@@ -1,7 +1,7 @@
 from circle.resources.abstract import (
     CreateableAPIResource,
     ListableAPIResource,
-    RetrievableAPIResource
+    RetrievableAPIResource,
 )
 
 
